package org.dromara.ems.info.service;

import org.dromara.ems.info.domain.UpsBatteryLifecycle;

import java.util.List;

/**
 * 行李系统UPS电池生命周期Service接口
 * 
 * @author Yinq
 * @date 2025-06-05
 */
public interface IUpsBatteryLifecycleService 
{
    /**
     * 查询行李系统UPS电池生命周期
     * 
     * @param id 行李系统UPS电池生命周期主键
     * @return 行李系统UPS电池生命周期
     */
    public UpsBatteryLifecycle selectUpsBatteryLifecycleById(Long id);

    /**
     * 查询行李系统UPS电池生命周期列表
     * 
     * @param upsBatteryLifecycle 行李系统UPS电池生命周期
     * @return 行李系统UPS电池生命周期集合
     */
    public List<UpsBatteryLifecycle> selectUpsBatteryLifecycleList(UpsBatteryLifecycle upsBatteryLifecycle);

    /**
     * 新增行李系统UPS电池生命周期
     * 
     * @param upsBatteryLifecycle 行李系统UPS电池生命周期
     * @return 结果
     */
    public int insertUpsBatteryLifecycle(UpsBatteryLifecycle upsBatteryLifecycle);

    /**
     * 修改行李系统UPS电池生命周期
     * 
     * @param upsBatteryLifecycle 行李系统UPS电池生命周期
     * @return 结果
     */
    public int updateUpsBatteryLifecycle(UpsBatteryLifecycle upsBatteryLifecycle);

    /**
     * 批量删除行李系统UPS电池生命周期
     * 
     * @param ids 需要删除的行李系统UPS电池生命周期主键集合
     * @return 结果
     */
    public int deleteUpsBatteryLifecycleByIds(Long[] ids);

    /**
     * 删除行李系统UPS电池生命周期信息
     * 
     * @param id 行李系统UPS电池生命周期主键
     * @return 结果
     */
    public int deleteUpsBatteryLifecycleById(Long id);

    /**
     * 导入行李系统UPS电池生命周期数据
     * 
     * @param dataList 行李系统UPS电池生命周期数据列表
     * @param updateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importUpsBatteryLifecycle(List<UpsBatteryLifecycle> dataList, Boolean updateSupport, String operName);
}
